# -*- coding: utf-8 -*-

__version__ = '0.2.1'

import re
import sys
import logging
import logging.config

from supervisor import childutils


logger = logging.getLogger('svdog')


class SVDog(object):
    excludes = None

    def __init__(self, config=None):
        if hasattr(config, 'LOGGING'):
            logging.config.dictConfig(config.LOGGING)

        self.excludes = getattr(config, 'EXCLUDES', None)

        self.stdin = sys.stdin
        self.stdout = sys.stdout

    def run(self):
        logger.info('running')

        while True:
            headers, payload = childutils.listener.wait(self.stdin, self.stdout)

            if not payload.endswith('\n'):
                payload = payload + '\n'

            pheaders, pdata = childutils.eventdata(payload)

            process_name = pheaders.get('processname')

            if process_name and self.excludes and list(filter(lambda x: re.match(x, process_name), self.excludes)):
                childutils.listener.ok(self.stdout)
                continue

            logger.error('%s\n%s', headers, payload)
            childutils.listener.ok(self.stdout)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
import argparse
import imp

import svdog


def build_parser():
    parser = argparse.ArgumentParser()
    parser.add_argument('-c', '--config', help='config file', action='store', required=False)
    parser.add_argument('-v', '--version', action='version', version='%s' % svdog.__version__)
    return parser


def load_config(filename):
    d = imp.new_module('config')
    d.__file__ = filename
    try:
        with open(filename) as config_file:
            exec(compile(config_file.read(), filename, 'exec'), d.__dict__)
    except IOError as e:
        e.strerror = 'Unable to load configuration file (%s)' % e.strerror
        raise
    return d


def run():
    args = build_parser().parse_args()

    app = svdog.SVDog(config=load_config(args.config) if args.config else None)
    try:
        app.run()
    except KeyboardInterrupt:
        sys.exit(0)
 
if __name__ == '__main__':
    run()



from setuptools import setup

setup(
    name="svdog",
    version='0.2.1',
    zip_safe=False,
    platforms='any',
    packages=['svdog'],
    install_requires=['supervisor', 'flylog'],
    scripts=['svdog/bin/run_svdog.py'],
    url="https://github.com/dantezhu/svdog",
    license="BSD",
    author="dantezhu",
    author_email="zny2008@gmail.com",
    description="supervisor's dog, should deploy with flylog",
)
